==> bug6.619.tgz: gpl.c <==
/*
 * Copyright James Morse Y2K+1
 * This is GPLed software 
 * please read COPYING
 *
 */

#include <stdio.h>
#include "gpl.h"

/* display GPL info */
void gnu(void)
{
        printf("************************************************************************\n");
        printf("*                                                                      *\n");
        printf("* Copyright (C) Y2K+1 James Morse   please read COPYING                *\n");
        printf("*                                                                      *\n");
        printf("* Questions and comments may be sent to: xbeastx@writeme.com           *\n");
        printf("*                                                                      *\n");
        printf("* This program is free software; you can redistribute it and/or modify *\n");
        printf("* it under the terms of the GNU General Public License as published by *\n");
        printf("* the Free Software Foundation; either version 2 of the License, or    *\n");
        printf("* (at your option) any later version.                                  *\n");
        printf("*                                                                      *\n");
        printf("* This program is distributed in the hope that it will be useful,      *\n");
        printf("* but WITHOUT ANY WARRANTY; without even the implied warranty of       *\n");
        printf("* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *\n");
        printf("* GNU General Public License for more details.                         *\n");
        printf("*                                                                      *\n");
        printf("* You should have received a copy of the GNU General Public License    *\n");
        printf("* along with this program; if not, write to the                        *\n");
        printf("*                                                                      *\n");
        printf("* Free Software Foundation, Inc.                                       *\n");
        printf("* 59 Temple Place, Suite 330                                           *\n");
        printf("* Boston, MA  02111-1307  USA                                          *\n");
        printf("*                                                                      *\n");
        printf("************************************************************************\n");
        return;
}

==> bug6.621.tgz: gpl.c <==
/*
 * Copyright James Morse Y2K +1, +2
 * This is GPLed software 
 * please read COPYING
 *
 */

#include <stdio.h>
#include "gpl.h"

/* display GPL info */
void gnu(void)
{
        printf("************************************************************************\n");
        printf("* Copyright (C) Y2K +1, +2 James Morse                                 *\n");
        printf("* please read COPYING                                                  *\n");
        printf("* Questions and comments may be sent to: xbeastx@yahoo.com             *\n");
        printf("*                                                                      *\n");
        printf("* This program is free software; you can redistribute it and/or modify *\n");
        printf("* it under the terms of the GNU General Public License as published by *\n");
        printf("* the Free Software Foundation; either version 2 of the License, or    *\n");
        printf("* (at your option) any later version.                                  *\n");
        printf("*                                                                      *\n");
        printf("* This program is distributed in the hope that it will be useful,      *\n");
        printf("* but WITHOUT ANY WARRANTY; without even the implied warranty of       *\n");
        printf("* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *\n");
        printf("* GNU General Public License for more details.                         *\n");
        printf("*                                                                      *\n");
        printf("* You should have received a copy of the GNU General Public License    *\n");
        printf("* along with this program; if not, write to the                        *\n");
        printf("*                                                                      *\n");
        printf("* Free Software Foundation, Inc.                                       *\n");
        printf("* 59 Temple Place, Suite 330                                           *\n");
        printf("* Boston, MA  02111-1307  USA                                          *\n");
        printf("************************************************************************\n");
        return;
}
